==> nomenclators_elprat-0.0.7-py3-none-any.whl: nomenclators_archetype/infrastructure/db/repository.py <==
"""
----------------------------------------------------------------------------------------------------
Written by Yovany Dominico Girón (y.dominico.giron@elprat.cat) for Ajuntament del Prat de Llobregat
----------------------------------------------------------------------------------------------------

----------------------------------------------------------------------------------------------------
"""
from abc import abstractmethod
from typing import Union
from sqlalchemy.orm import Session

from nomenclators_archetype.domain.commons import BaseSimpleNomenclator, BaseNomenclator
from nomenclators_archetype.domain.mapper.commons import BaseSimpleNomenclatorMapper, BaseNomenclatorMapper
from nomenclators_archetype.infrastructure.db.commons import BaseSimpleNomenclator as BaseSimpleNomenclatorEntity
from nomenclators_archetype.infrastructure.db.commons import BaseNomenclator as BaseNomenclatorEntity

from nomenclators_archetype.domain.repository.commons import JpaRepository

from nomenclators_archetype.infrastructure.db.builders import QueryBuilderImpl

NomenclatorId = Union[int, str]


class BaseSimpleNomenclatorRepository(JpaRepository[BaseSimpleNomenclator, NomenclatorId, BaseSimpleNomenclatorEntity]):
    """BaseSimpleNomenclator Repository Class"""

    def __init__(self, session: Session):
        self._session = session

    def get_builder(self):
        return QueryBuilderImpl()

    def get_session(self):
        return self._session

    def get_mapper(self):
        return BaseSimpleNomenclatorMapper()

    @abstractmethod
    def get_peristence_model(self):
        """Get persistence class"""


class BaseNomenclatorRepository(JpaRepository[BaseNomenclator, NomenclatorId, BaseNomenclatorEntity]):
    """BaseNomenclator Repository Class"""

    def __init__(self, session: Session):
        self._session = session

    def get_builder(self):
        return QueryBuilderImpl()

    def get_session(self):
        return self._session

    def get_mapper(self):
        return BaseNomenclatorMapper()

    @abstractmethod
    def get_peristence_model(self):
        """Get persistence class"""

==> nomenclators_elprat-0.0.8-py3-none-any.whl: nomenclators_archetype/infrastructure/db/repository.py <==
"""
----------------------------------------------------------------------------------------------------
Written by Yovany Dominico Girón (y.dominico.giron@elprat.cat) for Ajuntament del Prat de Llobregat
----------------------------------------------------------------------------------------------------

----------------------------------------------------------------------------------------------------
"""
from abc import abstractmethod
from typing import Union
from sqlalchemy.orm import Session

from nomenclators_archetype.domain.commons import BaseSimpleNomenclator, BaseNomenclator
from nomenclators_archetype.domain.mapper.commons import BaseSimpleNomenclatorMapper, BaseNomenclatorMapper
from nomenclators_archetype.infrastructure.db.commons import BaseSimpleNomenclator as BaseSimpleNomenclatorEntity
from nomenclators_archetype.infrastructure.db.commons import BaseNomenclator as BaseNomenclatorEntity

from nomenclators_archetype.domain.repository.commons import JpaRepository

from nomenclators_archetype.domain.repository.builders import QueryBuilder
from nomenclators_archetype.infrastructure.db.builders import QueryBuilderImpl

NomenclatorId = Union[int, str]


class BaseSimpleNomenclatorRepository(JpaRepository[BaseSimpleNomenclator, NomenclatorId, BaseSimpleNomenclatorEntity, Session, QueryBuilder]):
    """BaseSimpleNomenclator Repository Class"""

    def __init__(self, session: Session):
        self._session = session

    def get_builder(self) -> QueryBuilder:
        return QueryBuilderImpl()

    def get_session(self) -> Session:
        return self._session

    def get_mapper(self):
        return BaseSimpleNomenclatorMapper()

    @abstractmethod
    def get_peristence_model(self) -> BaseSimpleNomenclatorEntity:
        """Get persistence class"""


class BaseNomenclatorRepository(JpaRepository[BaseNomenclator, NomenclatorId, BaseNomenclatorEntity, Session, QueryBuilder]):
    """BaseNomenclator Repository Class"""

    def __init__(self, session: Session):
        self._session = session

    def get_builder(self):
        return QueryBuilderImpl()

    def get_session(self):
        return self._session

    def get_mapper(self):
        return BaseNomenclatorMapper()

    @abstractmethod
    def get_peristence_model(self) -> BaseNomenclatorEntity:
        """Get persistence class"""
